.. _api_label:

~~~~~~~~~~~~~~~~~
API Documentation
~~~~~~~~~~~~~~~~~

.. toctree::
   :maxdepth: 2
   :glob:


network
=======

.. automodule:: dhnx.network
    :members:
    :undoc-members:
    :show-inheritance:


gistools
========

dhnx.gistools.geometry_operations
---------------------------------

.. automodule:: dhnx.gistools.geometry_operations
    :members:
    :undoc-members:
    :show-inheritance:

dhnx.gistools.connect_points
----------------------------

.. automodule:: dhnx.gistools.connect_points
    :members:
    :undoc-members:
    :show-inheritance:


model
=====

.. automodule:: dhnx.model
    :members:
    :undoc-members:
    :show-inheritance:


optimization
============

dhnx.optimization.optimization_models
-------------------------------------

.. automodule:: dhnx.optimization.optimization_models
    :members:
    :undoc-members:
    :show-inheritance:

dhnx.optimization.dhs_nodes
-------------------------------------

.. automodule:: dhnx.optimization.dhs_nodes
    :members:
    :undoc-members:
    :show-inheritance:

dhnx.optimization.add_components
--------------------------------

.. automodule:: dhnx.optimization.add_components
    :members:
    :undoc-members:
    :show-inheritance:

dhnx.optimization.oemof_heatpipe
--------------------------------

.. automodule:: dhnx.optimization.oemof_heatpipe
    :members:
    :undoc-members:
    :show-inheritance:

.. _api_precalc_hydraulic_label:

dhnx.optimization.precalc_hydraulic
-----------------------------------

.. automodule:: dhnx.optimization.precalc_hydraulic
    :members:
    :undoc-members:
    :show-inheritance:


simulation
==========

.. automodule:: dhnx.simulation
    :members:
    :undoc-members:
    :show-inheritance:
    :private-members:
    :member-order: bysource
